Environment

Struct Environment 

pub struct Environment { /* private fields */ }
Structure to deal with environment variables

Implementations

Source

impl Environment

pub fn inherit() -> Self

Create a new Environment that inherits this process’ environment.

Examples
extern crate environment;
use std::ffi::OsString;

let e = environment::Environment::inherit().compile();
let e_: Vec<(OsString, OsString)> = ::std::env::vars_os().collect();

assert_eq!(e, e_);
pub fn empty() -> Self

Create a new Environment independent of the current process’s Environment

Examples
extern crate environment;

let e = environment::Environment::empty().compile();
assert_eq!(e, Vec::new());
pub fn insert<S1: Into<OsString>, S2: Into<OsString>>( self, key: S1, val: S2, ) -> Self

Insert a new entry into the custom variables for this environment object

Examples
extern crate environment;

use std::ffi::OsString;

let e = environment::Environment::empty().insert("foo", "bar").compile();
assert_eq!(e, vec![(OsString::from("foo"), OsString::from("bar"))]);
pub fn compile(self) -> Vec<(OsString, OsString)>

Compile Environment object